#' Initial step to import data into R
#' @param   working_dir       the directory in which the table you wish to analyse is located
#' @param   Table             the filename (including extension) of the table. e.g. = "chip15.csv"
#' @details This function imports a Biomark chip table into R. Alterations can be made to the chip in R before the object is used in the cleanavg() function.
#' @export

importchip<-function(working_dir,Table){

setwd(working_dir) 
f<-read.csv(Table,skip=11,header=TRUE,stringsAsFactors=FALSE)  #import the data straight from a table file (skips appropriate number of rows)

colnames(f)[c(2,3,5:18)]<-c("Sample","Stype","FAssay","Ftype","VAssay","Vtype","FamCt","FCalrConc","FamQ","FamCall","FamThresh",
                            "VicCt","VCalrConc","VicQ","VicCall","VicThresh")

trim.leading <- function (x)  sub("^\\s+", "", x)               # introduce a function to remove blanks from assay names
f[,5]<-trim.leading(f[,5])

f<-f[order(f$Sample,f$FAssay),] #sort the data by sample and assay

return(f)
}