#' Map Ct values of assay on sample plate
#' @param   chip        A chip imported using the importchip() function (pre-processing)
#' @param   pchip       The same chip after processing with the cleanavg() function ($data)
#' @param   assay       The assay to plot Ct values for (e.g., "mfl_psy")      
#' @details          This function will plot a heatmap of your sample plate, showing the Ct
#' values determined after processing using this package. The idea is that sample to sample 
#' contamination might be visualized using such a plot. Gray cells reflect NAs. The 5th through
#' 7th characters from your sample IDs will be plotted on each cell (should be fish ID number).
#' 
#' @export


sampleplate<-function(chip,pchip,assay){
# given a chip object (newly imported, not processed) 
# and a processed chip                 

plate<-data.frame(matrix(NA,nrow=8,ncol=12))
names<-data.frame(matrix(NA,nrow=8,ncol=12))

# given an assay
ass<-assay

for(i in 1:nrow(pchip)){
  a <- as.numeric(substr(chip[match(pchip[i,1],chip[,2]),1],2,3)) 
  crow <- floor((a-0.1)/12)+1
  ccol <- a-(crow-1)*12
    plate[crow,ccol]<-pchip[i,ass]
    names[crow,ccol]<-substr(pchip[i,1],5,7)
}


rownames(plate)<-c("A","B","C","D","E","F","G","H")
colnames(plate)<-1:12

plate2<-as.matrix(plate)
names2<-as.matrix(names)

windows(12,8)
#par(oma=c(1,1,1,1),bg="light grey")
heatmap.2(plate2,na.rm=TRUE,col=heat.colors(400),Rowv=NA,Colv=NA,density.info="none", na.color="gray",
          colsep=0:13,rowsep=0:13,cellnote=names2,sepwidth=c(0.05,0.05),sepcolor="black",trace="none",
          srtCol=0,main=colnames(pchip)[ass])
}