% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/normalize.R
\name{normalize}
\alias{normalize}
\title{Normalizes gene expression Ct values}
\usage{
normalize(
  chip,
  effic,
  type = "single",
  ref = "find",
  method = "ddCt_add",
  control = "contpoolpos"
)
}
\arguments{
\item{chip}{the data output from the cleanavg() function, or an object that is a combination of multiple chips.}

\item{effic}{the table output from the effcalc() function. Only needed when an efficiency correction (Pfaffl) method is used.}

\item{type}{determines whether data is from one or more chips. Either 'single' (default) or 'multiple.grp_avg'. See more below in Details.}

\item{ref}{pick reference genes: either use "find" and code will find them (assay names beginning with 'r') or specify column numbers to use a subset of ref genes.}

\item{method}{options are 'Pfaffl_fc', 'Pfaffl_add', 'ddCt_fc', 'ddCt_add', 'dCt', or 'copy_no'. Explained below}

\item{control}{for single chips, the name of a reference sample within the chip (most likely a pooled sample). For multiple chips, a vector representing row numbers.}
}
\description{
Normalizes gene expression Ct values
}
\details{
This function normalizes the biomarkers with several options for approach. While it carries the microbe data through to the end product, it does not alter microbe data. 
Control is by default one particular sample on the chip (for example, a pooled positive). Using an efficiency corrected method is recommended since the ddCt methods assume that efficiency is 100\%. Efficiency correction can be used when multiple chips are combined but note that it may not be appropriate since efficiencies vary between chips. Using efficiency averaged across chips is a potential solution but then might also defeat the purpose of efficiency correction in the first place.

'Pfaffl_fc', and 'Pfaffl_add' use efficiency correction. 'fc' stands for fold change, the results will be expressed as the fold change difference from the control. 'add' means that you will have 
positive or negative numbers, with the reference gene as zero. The 'copy_no' converts both target and reference genes to RNA copy number using the standard curve generated in the efficiency() function.
This is an efficiency correction approach (only available for use with single chips). 'ddCt' methods are very simliar to Pfaffl, except that efficiency is assumed to be 100\%. 'dCt' is simply the difference between an individual's target and reference genes, no control included. It is generally not recommended. 

The default for the 'ref=' argument allows the code to locate your reference genes and create a geomean for each sample. If you want to use a subset of reference genes, simply specify the column numbers here (e.g., ref=c(45,46))

Note that the user has flexibility in defining control groups for ddCt and Pfaffl calculations. Defining one entire treatment group as a control will allow for quick estimations of fold
change associated with treatment (using ddCt_fc). Control groups can be user defined on single chips by setting type='multiple' (even though it is just one chip). If you are using a single control, type in the row name, if multiple, a vector of row numbers.
}
