

c<-do.call("rbind", b)

#' Normalizes biomarker Ct values
#' @param chip  the data output from the cleanavg() function
#' @param effic the table output from the effcalc() function
#' @param method either 'Pfaffl' (efficiency corrected) or 'ddCt' (delta delta Ct)
#' @param control  the name of a reference sample within in the chip (most likely a pooled sample)
#' @details This function normalizes the biomarkers with the option of using two different approaches: efficiency corrected or regular delta delta CT. While it carries the microbe data through to the end product, it does not alter microbe data. 
#' Control could be one particular sample on the chip (for example, a pooled positive). There is not yet a method to use an average value from an entire population of fish from multiple chips (since this would require prior accounting for inter-chip variation in assay efficiency).
#' @return This function will return the same structure of the input 'cleanchip' but with normalized biomarkers
#' @export

normalize_multiple<-function(chips){#,effic,method="Pfaffl",control="contpoolpos"){
  rbind(chips)
}

  rcol<-NULL                             # create some empty objects
  bcol<-NULL
  mcol<-NULL
  misc<-NULL
  samps<-NULL
  
  if(length(chips))
  
  for(i in 1:nrow(chip)){
    if(substr(chip[i,1],1,4)!="cont"){samps<-append(samps,i)}                # identifies any rows that are not controls and collects them
  }
  
  for(i in 1:ncol(chip)){                                                     # this just figures out what the columns are (as in above functions)
    if(substr(colnames(chip)[i],1,1)=="r"){rcol<-append(rcol,i)}        			
    else{if(substr(colnames(chip)[i],1,1)=="b"){bcol<-append(bcol,i)}
         else{if(substr(colnames(chip)[i],1,1)=="m"){mcol<-append(mcol,i)}
              else{misc<-append(misc,i)}}
    }}
  
  if(method=="Pfaffl"){                               # this is what happens if you use "Pfaffl"
    
    c<-match(control,chip[,1])                        # find the control
    
    for (j in bcol){                                  # goes through one biomarker at a time
      for (i in samps){                                # for each non-control row
        ct.targ<-chip[c,j]-chip[i,j]                                                  # this caclulates Ct Target
        ct.ref<-exp(rowMeans(log(chip[c,rcol])))-exp(rowMeans(log(chip[i,rcol])))     # this caclulates Ct of the reference genes. Note that a geomean is used
        ern<-match(colnames(chip)[j],effic[,1])
        rern<-match(colnames(chip)[rcol],effic[,1])
        chip[i,j]<-(effic[ern,5]^ct.targ)/(mean(effic[rern,5])^ct.ref)           # this calculates R. Note that the reference gene efficiencies are averaged (arithmetic mean)
      }}}                                                                              # also note that result is placed directly back on chip
  
  else{
    if(method=="ddCt"){                               # this is what happens if you use "ddCt"
      
      c<-match(control,chip[,1])                        # find the control
      
      for (j in bcol){
        for (i in samps){
          ct.cont<-chip[c,j]-exp(rowMeans(log(chip[c,rcol])))     # difference between the "control" target and reference genes
          ct.trt<-chip[i,j]-exp(rowMeans(log(chip[i,rcol])))        # difference between the "treated" target and reference genes
          chip[i,j]<-2^(ct.cont-ct.trt)                             # calculate delta delta Ct and place on chip
        }}
    }}
  
  return(chip)        # note that reference genes, all controls, and microbes will still be expressed in Ct
}